Properties Methods Events Direct Link

# Class Ext.ux.tree.XmlTreeLoader

Package: | Ext.ux.tree
Defined In: | ux-all-debug.js
Class: | XmlTreeLoader
Extends: | Object

A TreeLoader that can convert an XML document into a hierarchy of Ext.tree.TreeNodes. Any text value included as a text node in the XML will be added to the parent node as an attribute called `innerText`. Also, the tag name of each XML node will be added to the tree node as an attribute called `tagName`.

By default, this class expects that your source XML will provide the necessary attributes on each node as expected by the Ext.tree.TreePanel to display and load properly. However, you can provide your own custom processing of node attributes by overriding the processNode method and modifying the attributes as needed before they are used to create the associated TreeNode.

## Public Properties

Property | Defined By
--- | ---
| XML_NODE_ELEMENT : Number XML element node (value 1, read-only) | XmlTreeLoader
| XML_NODE_ELEMENT : Number XML element node (value 1, read-only) | XmlTreeLoader
| XML_NODE_TEXT : Number XML text node (value 3, read-only) | XmlTreeLoader
| XML_NODE_TEXT : Number XML text node (value 3, read-only) | XmlTreeLoader

## Public Methods

This class has no public methods.

## Public Events

This class has no public events.